@@ -149,6 +149,24 @@ public:  // methods
     void deallocateDevice() const;
     void deallocateDevice(std::initializer_list<std::string> names) const;
     void deallocateDevice(std::initializer_list<int> indices) const;
+    void setDeviceNeedsUpdate(bool) const;
+    void setDeviceNeedsUpdate(bool, std::initializer_list<std::string> names) const;
+    void setDeviceNeedsUpdate(bool, std::initializer_list<int> indices) const;
+    void setHostNeedsUpdate(bool) const;
+    void setHostNeedsUpdate(bool, std::initializer_list<std::string> names) const;
+    void setHostNeedsUpdate(bool, std::initializer_list<int> indices) const;
+    void setDeviceNeedsUpdate() const;
+    void setDeviceNeedsUpdate(std::initializer_list<std::string> names) const;
+    void setDeviceNeedsUpdate(std::initializer_list<int> indices) const;
+    void setHostNeedsUpdate() const;
+    void setHostNeedsUpdate(std::initializer_list<std::string> names) const;
+    void setHostNeedsUpdate(std::initializer_list<int> indices) const;
+    void syncHost() const;
+    void syncHost(std::initializer_list<std::string> names) const;
+    void syncHost(std::initializer_list<int> indices) const;
+    void syncDevice() const;
+    void syncDevice(std::initializer_list<std::string> names) const;
+    void syncDevice(std::initializer_list<int> indices) const;
 
 
 
@@ -290,6 +308,18 @@ public:  // methods
     void deallocateDevice() const { get()->deallocateDevice(); }
     void deallocateDevice(std::initializer_list<std::string> names) const { get()->deallocateDevice(names); }
     void deallocateDevice(std::initializer_list<int> indices) const { get()->deallocateDevice(indices); }
+    void setDeviceNeedsUpdate(bool value) const { get()->setDeviceNeedsUpdate(value); }
+    void setDeviceNeedsUpdate(bool value, std::initializer_list<std::string> names) const { get()->setDeviceNeedsUpdate(value, names); }
+    void setDeviceNeedsUpdate(bool value, std::initializer_list<int> indices) const { get()->setDeviceNeedsUpdate(value, indices); }
+    void setHostNeedsUpdate(bool value) const { get()->setHostNeedsUpdate(value); }
+    void setHostNeedsUpdate(bool value, std::initializer_list<std::string> names) const { get()->setHostNeedsUpdate(value, names); }
+    void setHostNeedsUpdate(bool value, std::initializer_list<int> indices) const { get()->setHostNeedsUpdate(value, indices); }
+    void syncHost() const { get()->syncHost(); }
+    void syncHost(std::initializer_list<std::string> names) const { get()->syncHost(names); }
+    void syncHost(std::initializer_list<int> indices) const { get()->syncHost(indices); }
+    void syncDevice() const { get()->syncDevice(); }
+    void syncDevice(std::initializer_list<std::string> names) const { get()->syncDevice(names); }
+    void syncDevice(std::initializer_list<int> indices) const { get()->syncDevice(indices); }
 
     // Deprecated API
     DEPRECATED("use 'has' instead") bool has_field(const std::string& name) const { return get()->has(name); }
