@@ -18,6 +18,7 @@
 #include "atlas/field/FieldSet.h"
 #include "atlas/functionspace/NodeColumns.h"
 #include "atlas/grid/Grid.h"
+#include "atlas/grid/UnstructuredGrid.h"
 #include "atlas/library/config.h"
 #include "atlas/mesh/IsGhostNode.h"
 #include "atlas/mesh/Mesh.h"
@@ -223,6 +224,10 @@ NodeColumns::NodeColumns(Mesh mesh, const eckit::Configuration& config):
             nb_nodes_ = mesh_.nodes().size();
         }
     }
+
+    if (mesh_.grid()) {
+        grid_ = mesh_.grid();
+    }
 }
 
 NodeColumns::~NodeColumns() = default;
@@ -287,6 +292,10 @@ void NodeColumns::set_field_metadata(const eckit::Configuration& config, Field&
     if (config.has("type")) {
       field.metadata().set("type", config.getString("type"));
     }
+
+    if (config.has("vector_component")) {
+        field.metadata().set("vector_component", config.getSubConfiguration("vector_component"));
+    }
 }
 
 array::DataType NodeColumns::config_datatype(const eckit::Configuration& config) const {
@@ -641,6 +650,45 @@ const parallel::Checksum& NodeColumns::checksum() const {
 //  return checksum(fieldset);
 //}
 
+const Grid& NodeColumns::grid() const {
+    if (grid_) {
+        return grid_;
+    }
+
+    const auto& comm = mpi::comm(mpi_comm());
+    std::vector<PointXY> points;
+    if (comm.size() == 1) {
+        const auto xy = atlas::array::make_view<double, 2>(mesh_.nodes().xy());
+        for (auto i = 0; i < xy.shape(0); i++) {
+            points.push_back({xy(i, 0), xy(i, 1)});
+        }
+    } else {
+        std::vector<int> gidx;
+        std::vector<double> x, y;
+        const auto gidxView = array::make_view<gidx_t, 1>(global_index());
+        const auto ghostView = array::make_view<int, 1>(ghost());
+        const auto xy = atlas::array::make_view<double, 2>(mesh_.nodes().xy());
+        for (auto i = 0; i < xy.shape(0); i++) {
+            if (ghostView(i) == 0) {
+                gidx.push_back(gidxView(i));
+                x.push_back(xy(i, 0));
+                y.push_back(xy(i, 1));
+            }
+        }
+        eckit::mpi::Buffer<int> gidxBuffer(comm.size());
+        eckit::mpi::Buffer<double> xBuffer(comm.size());
+        eckit::mpi::Buffer<double> yBuffer(comm.size());
+        comm.allGatherv(gidx.begin(), gidx.end(), gidxBuffer);
+        comm.allGatherv(x.begin(), x.end(), xBuffer);
+        comm.allGatherv(y.begin(), y.end(), yBuffer);
+        points.reserve(gidxBuffer.buffer.size());
+        for (auto i : gidxBuffer.buffer) {
+            points[i - 1] = atlas::PointXY{xBuffer.buffer[i - 1], yBuffer.buffer[i - 1]};
+        }
+    }
+    grid_ = UnstructuredGrid(points);
+    return grid_;
+}
 
 }  // namespace detail
 
