@@ -121,6 +121,7 @@ static void init() {
 namespace detail {
 namespace grid {
 void force_link_CubedSphere();
+void force_link_CubedSphere2();
 void force_link_Gaussian();
 void force_link_LonLat();
 void force_link_Regional();
@@ -130,6 +131,7 @@ void force_link_Regional_var_resolution();
 
 const GridBuilder::Registry& GridBuilder::nameRegistry() {
     detail::grid::force_link_CubedSphere();
+    detail::grid::force_link_CubedSphere2();
     detail::grid::force_link_Gaussian();
     detail::grid::force_link_LonLat();
     detail::grid::force_link_Regional();
