@@ -70,10 +70,8 @@ void RegionalLinear2D::do_setup(const FunctionSpace& source,
   }
 
   // Source grid indices
-  const Field sourceFieldIndexI = sourceFs.index_i();
-  const Field sourceFieldIndexJ = sourceFs.index_j();
-  const auto sourceIndexIView = array::make_view<idx_t, 1>(sourceFieldIndexI);
-  const auto sourceIndexJView = array::make_view<idx_t, 1>(sourceFieldIndexJ);
+  const auto sourceIndexIView = array::make_indexview<idx_t, 1>(sourceFs.index_i());
+  const auto sourceIndexJView = array::make_indexview<idx_t, 1>(sourceFs.index_j());
   sourceSize_ = sourceFs.size();
 
   // Destination grid size
@@ -87,7 +85,11 @@ void RegionalLinear2D::do_setup(const FunctionSpace& source,
   std::vector<int> mpiTask(sourceNx*sourceNy, 0);
   for (size_t sourceJnode = 0; sourceJnode < sourceSize_; ++sourceJnode) {
     if (sourceGhostView(sourceJnode) == 0) {
-      mpiTask[(sourceIndexIView(sourceJnode)-1)*sourceNy+sourceIndexJView(sourceJnode)-1] = comm_.rank();
+      idx_t idx = sourceIndexIView(sourceJnode)*static_cast<idx_t>(sourceNy)+sourceIndexJView(sourceJnode);
+      if (idx < 0 || idx >= mpiTask.size()) {
+        throw_OutOfRange("mpiTask", idx, mpiTask.size(), Here());
+      }
+      mpiTask[idx] = comm_.rank();
     }
   }
   comm_.allReduceInPlace(mpiTask.begin(), mpiTask.end(), eckit::mpi::sum());
@@ -206,7 +208,7 @@ void RegionalLinear2D::do_setup(const FunctionSpace& source,
     std::vector<int> gij;
     for (size_t sourceJnode = 0; sourceJnode < sourceSize_; ++sourceJnode) {
       if (sourceGhostView(sourceJnode) == 0) {
-        gij.push_back((sourceIndexIView(sourceJnode)-1)*sourceNy+sourceIndexJView(sourceJnode)-1);
+        gij.push_back(sourceIndexIView(sourceJnode)*sourceNy+sourceIndexJView(sourceJnode));
       } else {
         gij.push_back(-1);
       }
