@@ -88,6 +88,9 @@ public:
     /// Copy assign from other SparseMatrixStorage, takes ownership!
     SparseMatrixStorage& operator=(const SparseMatrixStorage& other);
 
+    // Remove all storage, make empty
+    void clear();
+
     /// Empty if rows and cols are zero.
     bool empty() const { return rows_ == 0 && cols_ == 0; }
 
@@ -109,9 +112,9 @@ public:
 
     bool deviceNeedsUpdate() const;
 
-    void setHostNeedsUpdate(bool v) const;
+    void setHostNeedsUpdate(bool) const;
 
-    void setDeviceNeedsUpdate(bool v) const;
+    void setDeviceNeedsUpdate(bool) const;
 
     bool deviceAllocated() const;
 
@@ -119,6 +122,10 @@ public:
 
     void deallocateDevice() const;
 
+    void syncHost() const;
+
+    void syncDevice() const;
+
     static SparseMatrixStorage make(
         std::size_t rows,
         std::size_t cols,
@@ -287,4 +294,4 @@ inline SparseMatrixView<Value,Index> make_device_view(const SparseMatrixStorage&
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace linalg
-}  // namespace atlas
\ No newline at end of file
+}  // namespace atlas
