@@ -10,9 +10,11 @@
 
 #pragma once
 
+#include <iostream>
 #include <memory>
 #include <string>
 
+#include "atlas/projection/Jacobian.h"
 #include "atlas/util/Factory.h"
 #include "atlas/util/NormaliseLongitude.h"
 #include "atlas/util/Object.h"
@@ -32,127 +34,18 @@ class Config;
 }
 }  // namespace atlas
 
-namespace atlas {
-namespace projection {
-namespace detail {
+namespace atlas::projection::detail {
 
 class ProjectionImpl : public util::Object {
 public:
-    using Spec = atlas::util::Config;
-    class Jacobian : public std::array<std::array<double, 2>, 2> {
-    public:
-        static Jacobian identity() {
-            Jacobian id;
-            id[0] = {1.0, 0.0};
-            id[1] = {0.0, 1.0};
-            return id;
-        }
-
-        Jacobian inverse() const {
-            const Jacobian& jac = *this;
-            Jacobian inv;
-            double det = jac[0][0] * jac[1][1] - jac[0][1] * jac[1][0];
-            inv[0][0]  = +jac[1][1] / det;
-            inv[0][1]  = -jac[0][1] / det;
-            inv[1][0]  = -jac[1][0] / det;
-            inv[1][1]  = +jac[0][0] / det;
-            return inv;
-        };
-
-        Jacobian transpose() const {
-            Jacobian tra = *this;
-            std::swap(tra[0][1], tra[1][0]);
-            return tra;
-        };
-
-        Jacobian operator-(const Jacobian& jac2) const {
-            const Jacobian& jac1 = *this;
-            Jacobian jac;
-            jac[0][0] = jac1[0][0] - jac2[0][0];
-            jac[0][1] = jac1[0][1] - jac2[0][1];
-            jac[1][0] = jac1[1][0] - jac2[1][0];
-            jac[1][1] = jac1[1][1] - jac2[1][1];
-            return jac;
-        }
-
-        Jacobian operator+(const Jacobian& jac2) const {
-            const Jacobian& jac1 = *this;
-            Jacobian jac;
-            jac[0][0] = jac1[0][0] + jac2[0][0];
-            jac[0][1] = jac1[0][1] + jac2[0][1];
-            jac[1][0] = jac1[1][0] + jac2[1][0];
-            jac[1][1] = jac1[1][1] + jac2[1][1];
-            return jac;
-        }
-
-        double norm() const {
-            const Jacobian& jac = *this;
-            return sqrt(jac[0][0] * jac[0][0] + jac[0][1] * jac[0][1] + jac[1][0] * jac[1][0] + jac[1][1] * jac[1][1]);
-        }
-
-        Jacobian operator*(const Jacobian& jac2) const {
-            const Jacobian& jac1 = *this;
-            Jacobian jac;
-            jac[0][0] = jac1[0][0] * jac2[0][0] + jac1[0][1] * jac2[1][0];
-            jac[0][1] = jac1[0][0] * jac2[0][1] + jac1[0][1] * jac2[1][1];
-            jac[1][0] = jac1[1][0] * jac2[0][0] + jac1[1][1] * jac2[1][0];
-            jac[1][1] = jac1[1][0] * jac2[0][1] + jac1[1][1] * jac2[1][1];
-            return jac;
-        }
-
-        double dx_dlon() const {
-            const Jacobian& jac = *this;
-            return jac[JDX][JDLON];
-        }
-        double dy_dlon() const {
-            const Jacobian& jac = *this;
-            return jac[JDY][JDLON];
-        }
-        double dx_dlat() const {
-            const Jacobian& jac = *this;
-            return jac[JDX][JDLAT];
-        }
-        double dy_dlat() const {
-            const Jacobian& jac = *this;
-            return jac[JDY][JDLAT];
-        }
-
-        double dlon_dx() const {
-            const Jacobian& jac = *this;
-            return jac[JDLON][JDX];
-        }
-        double dlon_dy() const {
-            const Jacobian& jac = *this;
-            return jac[JDLON][JDY];
-        }
-        double dlat_dx() const {
-            const Jacobian& jac = *this;
-            return jac[JDLAT][JDX];
-        }
-        double dlat_dy() const {
-            const Jacobian& jac = *this;
-            return jac[JDLAT][JDY];
-        }
-
-    private:
-        enum
-        {
-            JDX = 0,
-            JDY = 1
-        };
-        enum
-        {
-            JDLON = 0,
-            JDLAT = 1
-        };
-    };
+    using Spec     = atlas::util::Config;
+    using Jacobian = projection::Jacobian;
 
 public:
     static const ProjectionImpl* create(const eckit::Parametrisation& p);
     static const ProjectionImpl* create(const std::string& type, const eckit::Parametrisation& p);
 
-    ProjectionImpl()          = default;
-    virtual ~ProjectionImpl() = default;  // destructor should be virtual
+    ProjectionImpl() = default;
 
     virtual std::string type() const = 0;
 
@@ -225,7 +118,7 @@ public:
     protected:
         const ProjectionImpl& projection_;
         const PointXY H_;
-        const double normH_;
+        const double invnH_;
         const double refLongitude_;
         PointLonLat xy2lonlat(const PointXY& p) const;
     };
@@ -292,10 +185,8 @@ public:
     static std::string classNamePrefix() { return ""; }  // deliberately empty
     static std::string typePrefix() { return ""; }       // deliberately empty
 
-    void rotate(double*) const { /* do nothing */
-    }
-    void unrotate(double*) const { /* do nothing */
-    }
+    void rotate(double*) const { /* do nothing */ }
+    void unrotate(double*) const { /* do nothing */ }
 
     bool rotated() const { return false; }
 
@@ -313,6 +204,4 @@ void atlas__Projection__xy2lonlat(const ProjectionImpl* This, const double x, co
 void atlas__Projection__lonlat2xy(const ProjectionImpl* This, const double lon, const double lat, double& x, double& y);
 }
 
-}  // namespace detail
-}  // namespace projection
-}  // namespace atlas
+}  // namespace atlas::projection::detail
