@@ -108,6 +108,15 @@ public:
     virtual void dirtrans_wind2vordiv(const Field& gpwind, Field& spvor, Field& spdiv,
                                       const eckit::Configuration& = util::NoConfig()) const override;
 
+    virtual void dirtrans_adj(const Field& spfield, Field& gpfield,
+                              const eckit::Configuration& = util::NoConfig()) const override;
+
+    virtual void dirtrans_adj(const FieldSet& spfields, FieldSet& gpfields,
+                              const eckit::Configuration& = util::NoConfig()) const override;
+
+    virtual void dirtrans_wind2vordiv_adj(const Field& spvor, const Field& spdiv, Field& gpwind,
+                                          const eckit::Configuration& = util::NoConfig()) const override;
+
     virtual void invtrans(const Field& spfield, Field& gpfield,
                           const eckit::Configuration& = util::NoConfig()) const override;
 
@@ -235,64 +244,100 @@ public:
 public:
     void __dirtrans(const functionspace::StructuredColumns&, const Field& gpfield, const functionspace::Spectral&,
                     Field& spfield, const eckit::Configuration& = util::NoConfig()) const;
-    void __dirtrans(const functionspace::StructuredColumns&, const FieldSet& gpfields, const functionspace::Spectral&,
-                    FieldSet& spfields, const eckit::Configuration& = util::NoConfig()) const;
-
     void __dirtrans(const functionspace::NodeColumns&, const Field& gpfield, const functionspace::Spectral&,
                     Field& spfield, const eckit::Configuration& = util::NoConfig()) const;
+
+    void __dirtrans(const functionspace::StructuredColumns&, const FieldSet& gpfields, const functionspace::Spectral&,
+                    FieldSet& spfields, const eckit::Configuration& = util::NoConfig()) const;
     void __dirtrans(const functionspace::NodeColumns&, const FieldSet& gpfields, const functionspace::Spectral&,
                     FieldSet& spfields, const eckit::Configuration& = util::NoConfig()) const;
 
+    void __dirtrans_wind2vordiv(const functionspace::StructuredColumns&, const Field& gpwind,
+                                const functionspace::Spectral&, Field& spvor, Field& spdiv,
+                                const eckit::Configuration& = util::NoConfig()) const;
     void __dirtrans_wind2vordiv(const functionspace::NodeColumns&, const Field& gpwind, const functionspace::Spectral&,
                                 Field& spvor, Field& spdiv, const eckit::Configuration& = util::NoConfig()) const;
 
+    void __dirtrans_adj(const functionspace::Spectral&, const Field& spfield,
+                        const functionspace::StructuredColumns&, Field& gpfield,
+                        const eckit::Configuration& = util::NoConfig()) const;
+    void __dirtrans_adj(const functionspace::Spectral&, const Field& spfield,
+                        const functionspace::NodeColumns&, Field& gpfield,
+                        const eckit::Configuration& = util::NoConfig()) const;
+
+    void __dirtrans_adj(const functionspace::Spectral&, const FieldSet& spfields,
+                        const functionspace::StructuredColumns&, FieldSet& gpfields,
+                        const eckit::Configuration& = util::NoConfig()) const;
+    void __dirtrans_adj(const functionspace::Spectral&, const FieldSet& spfields,
+                        const functionspace::NodeColumns&, FieldSet& gpfields,
+                        const eckit::Configuration& = util::NoConfig()) const;
+
+    void __dirtrans_wind2vordiv_adj(const functionspace::Spectral&, const Field& spvor, const Field& spdiv,
+                                    const functionspace::StructuredColumns&, Field& gpwind,
+                                    const eckit::Configuration& = util::NoConfig()) const;
+    void __dirtrans_wind2vordiv_adj(const functionspace::Spectral&, const Field& spvor, const Field& spdiv,
+                                    const functionspace::NodeColumns&, Field& gpwind,
+                                    const eckit::Configuration& = util::NoConfig()) const;
+
     void __invtrans(const functionspace::Spectral&, const Field& spfield, const functionspace::StructuredColumns&,
                     Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
+    void __invtrans(const functionspace::Spectral&, const Field& spfield, const functionspace::NodeColumns&,
+                    Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
 
     void __invtrans(const functionspace::Spectral&, const FieldSet& spfields, const functionspace::StructuredColumns&,
                     FieldSet& gpfields, const eckit::Configuration& = util::NoConfig()) const;
-
-    void __invtrans(const functionspace::Spectral&, const Field& spfield, const functionspace::NodeColumns&,
-                    Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
-
     void __invtrans(const functionspace::Spectral&, const FieldSet& spfields, const functionspace::NodeColumns&,
                     FieldSet& gpfields, const eckit::Configuration& = util::NoConfig()) const;
 
-    void __invtrans_vordiv2wind(const functionspace::Spectral&, const Field& spvor, const Field& spdiv,
-                                const functionspace::NodeColumns&, Field& gpwind,
-                                const eckit::Configuration& = util::NoConfig()) const;
-
+    void __invtrans_grad(const functionspace::Spectral& sp, const Field& spfield,
+                         const functionspace::StructuredColumns& gp, Field& gradfield,
+                         const eckit::Configuration& = util::NoConfig()) const;
     void __invtrans_grad(const functionspace::Spectral& sp, const Field& spfield, const functionspace::NodeColumns& gp,
                          Field& gradfield, const eckit::Configuration& = util::NoConfig()) const;
 
+    void __invtrans_grad(const functionspace::Spectral& sp, const FieldSet& spfields,
+                         const functionspace::StructuredColumns& gp, FieldSet& gradfields,
+                         const eckit::Configuration& = util::NoConfig()) const;
     void __invtrans_grad(const functionspace::Spectral& sp, const FieldSet& spfields,
                          const functionspace::NodeColumns& gp, FieldSet& gradfields,
                          const eckit::Configuration& = util::NoConfig()) const;
 
+    void __invtrans_vordiv2wind(const functionspace::Spectral&, const Field& spvor, const Field& spdiv,
+                                const functionspace::StructuredColumns&, Field& gpwind,
+                                const eckit::Configuration& = util::NoConfig()) const;
+    void __invtrans_vordiv2wind(const functionspace::Spectral&, const Field& spvor, const Field& spdiv,
+                                const functionspace::NodeColumns&, Field& gpwind,
+                                const eckit::Configuration& = util::NoConfig()) const;
 
     void __invtrans_adj(const functionspace::Spectral&, Field& spfield, const functionspace::StructuredColumns&,
                         const Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
+    void __invtrans_adj(const functionspace::Spectral&, Field& spfield, const functionspace::NodeColumns&,
+                        const Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
 
     void __invtrans_adj(const functionspace::Spectral&, FieldSet& spfields, const functionspace::StructuredColumns&,
                         const FieldSet& gpfields, const eckit::Configuration& = util::NoConfig()) const;
-
-    void __invtrans_adj(const functionspace::Spectral&, Field& spfield, const functionspace::NodeColumns&,
-                        const Field& gpfield, const eckit::Configuration& = util::NoConfig()) const;
-
     void __invtrans_adj(const functionspace::Spectral&, FieldSet& spfields, const functionspace::NodeColumns&,
                         const FieldSet& gpfields, const eckit::Configuration& = util::NoConfig()) const;
 
-    void __invtrans_vordiv2wind_adj(const functionspace::Spectral&, Field& spvor, Field& spdiv,
-                                    const functionspace::NodeColumns&, const Field& gpwind,
-                                    const eckit::Configuration& = util::NoConfig()) const;
-
+    void __invtrans_grad_adj(const functionspace::Spectral& sp, Field& spfield,
+                             const functionspace::StructuredColumns& gp, const Field& gradfield,
+                             const eckit::Configuration& = util::NoConfig()) const;
     void __invtrans_grad_adj(const functionspace::Spectral& sp, Field& spfield, const functionspace::NodeColumns& gp,
                              const Field& gradfield, const eckit::Configuration& = util::NoConfig()) const;
 
+    void __invtrans_grad_adj(const functionspace::Spectral& sp, FieldSet& spfields,
+                             const functionspace::StructuredColumns& gp, const FieldSet& gradfields,
+                             const eckit::Configuration& = util::NoConfig()) const;
     void __invtrans_grad_adj(const functionspace::Spectral& sp, FieldSet& spfields,
                              const functionspace::NodeColumns& gp, const FieldSet& gradfields,
                              const eckit::Configuration& = util::NoConfig()) const;
 
+    void __invtrans_vordiv2wind_adj(const functionspace::Spectral&, Field& spvor, Field& spdiv,
+                                    const functionspace::StructuredColumns&, const Field& gpwind,
+                                    const eckit::Configuration& = util::NoConfig()) const;
+    void __invtrans_vordiv2wind_adj(const functionspace::Spectral&, Field& spvor, Field& spdiv,
+                                    const functionspace::NodeColumns&, const Field& gpwind,
+                                    const eckit::Configuration& = util::NoConfig()) const;
 
 public:
     void specnorm(const int nb_fields, const double spectra[], double norms[], int rank = 0) const;
