@@ -119,7 +119,10 @@ void Metadata::broadcast(Metadata& dest, idx_t root) const {
 }
 
 
-Metadata& Metadata::set(const eckit::LocalConfiguration& other) {
+Metadata& Metadata::set(const eckit::Configuration& other) {
+#if ATLAS_ECKIT_VERSION_AT_LEAST(1, 26, 0) || ATLAS_ECKIT_DEVELOP
+    LocalConfiguration::set(other);
+#else
     eckit::Value& root = const_cast<eckit::Value&>(get());
     auto& other_root   = other.get();
     std::vector<string> other_keys;
@@ -127,6 +130,7 @@ Metadata& Metadata::set(const eckit::LocalConfiguration& other) {
     for (auto& key : other_keys) {
         root[key] = other_root[key];
     }
+#endif
     return *this;
 }
 
