@@ -31,10 +31,23 @@ namespace test {
 
 //-----------------------------------------------------------------------------
 
+template <typename T>
+mdspan<T,dims<1>> make_mdspan(std::vector<T>& v) {
+    return mdspan<T,dims<1>>{v.data(), v.size()};
+}
+template <typename T, size_t N>
+mdspan<T,extents<size_t,dynamic_extent,N>> make_mdspan(std::vector<std::array<T,N>>& v) {
+    return mdspan<T,extents<size_t,dynamic_extent,N>>{reinterpret_cast<T*>(v.data()), v.size()};
+}
+
+//-----------------------------------------------------------------------------
+
 CASE("test_cs_c2_mesh_parallel") {
     ATLAS_ASSERT(mpi::comm().size() == 6);
     const int rank = mpi::comm().rank();
 
+    constexpr gidx_t global_index_base = 1;
+
     // Coordinates of the C2 LFRic cubed-sphere grid: grid("CS-LFR-2");
     const std::vector<double> global_lons = {337.5, 22.5,  337.5, 22.5,   // +x
                                              67.5,  112.5, 67.5,  112.5,  // +y
@@ -154,8 +167,15 @@ CASE("test_cs_c2_mesh_parallel") {
     const MeshBuilder mesh_builder{};
 
     SECTION("Build Mesh without a Grid") {
-        const Mesh mesh = mesh_builder(lons, lats, ghosts, global_indices, remote_indices, remote_index_base, partitions,
-                                       tri_boundary_nodes, tri_global_indices, quad_boundary_nodes, quad_global_indices);
+        const Mesh mesh = mesh_builder(
+            make_mdspan(global_indices),
+            make_mdspan(lons), make_mdspan(lats), make_mdspan(lons), make_mdspan(lats),
+            make_mdspan(ghosts), make_mdspan(partitions), make_mdspan(remote_indices), remote_index_base,
+            make_mdspan(tri_global_indices), make_mdspan(tri_boundary_nodes),
+            make_mdspan(quad_global_indices), make_mdspan(quad_boundary_nodes),
+            global_index_base);
+        // const Mesh mesh = mesh_builder(lons, lats, ghosts, global_indices, remote_indices, remote_index_base, partitions,
+        //                                tri_boundary_nodes, tri_global_indices, quad_boundary_nodes, quad_global_indices);
 
         helper::check_mesh_nodes_and_cells(mesh, lons, lats, ghosts, global_indices, remote_indices, remote_index_base,
                                            partitions, tri_boundary_nodes, tri_global_indices, quad_boundary_nodes,
@@ -190,9 +210,17 @@ CASE("test_cs_c2_mesh_parallel") {
         config.set("grid.xy", global_lonlats);
         config.set("validate", true);
 
-        const Mesh mesh = mesh_builder(lons, lats, ghosts, global_indices, remote_indices, remote_index_base, partitions,
-                                       tri_boundary_nodes, tri_global_indices, quad_boundary_nodes, quad_global_indices,
-                                       config);
+        // const Mesh mesh = mesh_builder(lons, lats, ghosts, global_indices, remote_indices, remote_index_base, partitions,
+        //                                tri_boundary_nodes, tri_global_indices, quad_boundary_nodes, quad_global_indices,
+        //                                config);
+        const Mesh mesh = mesh_builder(
+            make_mdspan(global_indices),
+            make_mdspan(lons), make_mdspan(lats), make_mdspan(lons), make_mdspan(lats),
+            make_mdspan(ghosts), make_mdspan(partitions), make_mdspan(remote_indices), remote_index_base,
+            make_mdspan(tri_global_indices), make_mdspan(tri_boundary_nodes),
+            make_mdspan(quad_global_indices), make_mdspan(quad_boundary_nodes),
+            global_index_base,
+            config);
 
         helper::check_mesh_nodes_and_cells(mesh, lons, lats, ghosts, global_indices, remote_indices, remote_index_base,
                                            partitions, tri_boundary_nodes, tri_global_indices, quad_boundary_nodes,
@@ -205,9 +233,17 @@ CASE("test_cs_c2_mesh_parallel") {
         util::Config config{};
         config.set("grid.type", "unstructured");
 
-        const Mesh mesh = mesh_builder(lons, lats, ghosts, global_indices, remote_indices, remote_index_base, partitions,
-                                       tri_boundary_nodes, tri_global_indices, quad_boundary_nodes, quad_global_indices,
-                                       config);
+        // const Mesh mesh = mesh_builder(lons, lats, ghosts, global_indices, remote_indices, remote_index_base, partitions,
+        //                                tri_boundary_nodes, tri_global_indices, quad_boundary_nodes, quad_global_indices,
+        //                                config);
+        const Mesh mesh = mesh_builder(
+            make_mdspan(global_indices),
+            make_mdspan(lons), make_mdspan(lats), make_mdspan(lons), make_mdspan(lats),
+            make_mdspan(ghosts), make_mdspan(partitions), make_mdspan(remote_indices), remote_index_base,
+            make_mdspan(tri_global_indices), make_mdspan(tri_boundary_nodes),
+            make_mdspan(quad_global_indices), make_mdspan(quad_boundary_nodes),
+            global_index_base,
+            config);
 
         helper::check_mesh_nodes_and_cells(mesh, lons, lats, ghosts, global_indices, remote_indices, remote_index_base,
                                            partitions, tri_boundary_nodes, tri_global_indices, quad_boundary_nodes,
